@@ -61,13 +61,24 @@ def getCaseInfo(text: str):
 	except (IndexError, AttributeError):
 		pass
 	try:
-		street_addr = re.search(r'(?:Address 1\:)(.+)', str(text), re.MULTILINE).group(1).strip()
-		zip_code = re.search(r'(?:Zip\: ).+', str(text), re.MULTILINE).group().strip()
-		city = re.search(r'(?:City\: ).*(?:State\: ).*', str(text), re.MULTILINE).group(1).strip()
-		state = re.search(r'(?:City\: ).*(?:State\: ).*', str(text), re.MULTILINE).group(2).strip()
-		address = street_addr + "	" + city + ", " + state + " " + zip_code
-	except(IndexError, AttributeError):
-		pass
+		street_addr = re.search(r'(Address 1\:)(.+)', str(text), re.MULTILINE).group(2).strip()
+	except (IndexError, AttributeError):
+		street_addr = ""
+	try:
+		zip_code = re.search(r'(Zip\: )(.+)', str(text), re.MULTILINE).group(2).strip()	
+	except (IndexError, AttributeError):
+		zip_code = ""
+	try:
+		city = re.search(r'(City\: )(.*)(State\: )(.*)', str(text), re.MULTILINE).group(2).strip()
+	except (IndexError, AttributeError):
+		city = ""
+	try:
+		state = re.search(r'(?:City\: ).*(?:State\: ).*', str(text), re.MULTILINE).group(4).strip()
+	except (IndexError, AttributeError):
+		state = ""
+	
+	address = street_addr + "	" + city + ", " + state + " " + zip_code
+
 	case = [
 		case_num,
 		name,
@@ -116,8 +127,10 @@ def getFeeSheet(text: str):
 
 def getCharges(text: str):
 	# get all charges matches
-	c = pd.Series([re.findall(r'(\d{3}\s{1}.{1,100}?.{3}-.{3}-.{3}.{0,100}+)', str(text), re.MULTILINE)])
-	c = c.str.replace("Sentences","").replace("Sentence","").replace("SentencesSentence","").replace("Sentence 1","").replace("Financial","").strip()
+	ch = re.findall(r'(\d{3}\s{1}.{1,100}?.{3}-.{3}-.{3}.{0,100}+)', str(text), re.MULTILINE)
+	c = []
+	for a in ch:
+		c.append(str(a).replace("Sentences","").replace("Sentence","").replace("SentencesSentence","").replace("Sentence 1","").replace("Financial","").strip())
 	cind = range(0, len(c))
 	charges = pd.DataFrame({'Charges': c},index=cind)
 	# find table fields
